import { ComponentOptionsMixin } from 'vue';
import { ComponentProvideOptions } from 'vue';
import { DefineComponent } from 'vue';
import { PublicProps } from 'vue';

export declare const CloudFilePlayer: DefineComponent<    {
/**
* 文件 ID or 文件元信息
*/
file: string | FileMetas | undefined;
/**
* 播放引擎
*/
engine?: "image" | "presentation";
/**
* 播放的初始页
*/
defaultPage?: number;
/**
* 播放的初始页内第 N 个动画
*/
defaultStep?: number;
/**
* 是否垂直播放
*/
vertical?: boolean;
/**
* 暗黑风格
*/
dark?: boolean;
/**
* 引擎基础 URL
*
* 用于按需载入引擎的脚本、WASM、Iframe等。
*/
engineBaseUrl?: string;
/**
* 图文版文档播放引擎 Iframe 地址
*
* (用于开发时设置)
*/
imageEngineIframeUrl?: string;
/**
* 动画版演示文稿播放引擎 Iframe 地址
*/
presentationAnimationEngineIframeUrl?: string;
}, {
prev: () => Promise<void>;
next: () => Promise<void>;
goto: (pos: Position) => Promise<void>;
thumbs: () => Thumb[];
}, {}, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {
paginationChange: (pagination: Pagination) => any;
}, string, PublicProps, Readonly<{
/**
* 文件 ID or 文件元信息
*/
file: string | FileMetas | undefined;
/**
* 播放引擎
*/
engine?: "image" | "presentation";
/**
* 播放的初始页
*/
defaultPage?: number;
/**
* 播放的初始页内第 N 个动画
*/
defaultStep?: number;
/**
* 是否垂直播放
*/
vertical?: boolean;
/**
* 暗黑风格
*/
dark?: boolean;
/**
* 引擎基础 URL
*
* 用于按需载入引擎的脚本、WASM、Iframe等。
*/
engineBaseUrl?: string;
/**
* 图文版文档播放引擎 Iframe 地址
*
* (用于开发时设置)
*/
imageEngineIframeUrl?: string;
/**
* 动画版演示文稿播放引擎 Iframe 地址
*/
presentationAnimationEngineIframeUrl?: string;
}> & Readonly<{
onPaginationChange?: ((pagination: Pagination) => any) | undefined;
}>, {
dark: boolean;
defaultPage: number;
defaultStep: number;
vertical: boolean;
engine: "image" | "presentation";
}, {}, {}, {}, string, ComponentProvideOptions, false, {}, any>;

/**
 * 文件元信息
 */
export declare interface FileMetas {
    id: string;
    name: string;
    type: FileType;
    page?: number;
    thumb?: string;
    image?: {
        imageUrlPrefix: string;
        encryptIv?: string;
        encryptKey?: string;
    };
    animation?: {
        infoUrl: string;
        pageUrlPrefix: string;
        resourceUri: string;
        encryptKey?: string;
        encryptIv?: string;
    };
}

/**
 * 文件源
 */
export declare interface FileSource {
    /**
     * 文件元信息
     */
    metas?: FileMetas;
    /**
     * 文件 Token
     */
    token?: string;
}

/**
 * 文件类型
 *  * Word: Word 文档
 *  * PDF: PDF 文档
 *  * Presentation: 演示文稿（幻灯片）
 *  * Unknown: 未知
 */
export declare type FileType = "Word" | "PDF" | "Presentation" | "Unknown";

/**
 * 分页对象
 */
export declare interface Pagination {
    /**
     * 总页数
     */
    total: number;
    /**
     * 当前页数
     */
    current: number;
    /**
     * 当前步骤（即当前页的第 N 个动画）
     */
    step?: number;
}

/**
 * 播放器事件
 */
export declare interface PlayerEvents {
    /**
     * 已准备好
     */
    ready: undefined;
    /**
     * 页码更新
     */
    pageUpdate: Position;
    /**
     * 分页变更
     */
    paginationChange: Pagination;
    /**
     * 开始播放事件，打开课件加载完成后触发
     */
    play: PlayEvent;
}

/**
 * 播放器初始化参数
 */
export declare interface PlayerOptions {
    /**
     * 引擎基础 URL
     *
     * 用于按需载入引擎的脚本、WASM、Iframe等。
     */
    engineBaseUrl: string;
    /**
     * 图文版文档播放引擎 Iframe 地址
     *
     * (用于开发时设置)
     */
    imageEngineIframeUrl: string;
    /**
     * 动画版演示文稿播放引擎 Iframe 地址
     */
    presentationAnimationEngineIframeUrl: string;
    /**
     * 暗黑风格
     */
    dark: boolean;
}

/**
 * 播放事件
 */
export declare interface PlayEvent {
    /**
     * 文件名
     */
    name: string;
    /**
     * 开始播放的分页对象
     */
    pagination: Pagination;
}

/**
 * 播放选项
 */
export declare interface PlayOptions {
    /**
     * 播放初始页
     */
    defaultPage: number;
    /**
     * 播放初始动画步骤
     */
    defaultStep: number;
    /**
     * 是否垂直播放
     */
    vertical: boolean;
}

/**
 * 点位
 */
export declare interface Position {
    /**
     * 页码
     */
    page: number;
    /**
     * 第 N 个动画
     */
    step?: number;
}

/**
 * 缩略图
 */
export declare interface Thumb {
    /**
     * 页码
     */
    page: number;
    /**
     * URL
     */
    url: string;
}

export { }
